<!DOCTYPE html>
<html lang="en">
<head>
    {% block starthead %}{% endblock %}
    <title>Glitter Demo</title>
</head>
<body>
    {% block startbody %}{% endblock %}
    {% block content %}{% endblock %}
</body>
</html>
