# -*- coding: utf-8 -*-

from __future__ import unicode_literals


POSITION_IMAGE_LEFT = 'image-left'
POSITION_IMAGE_RIGHT = 'image-right'


POSITION_CHOICES = (
    (POSITION_IMAGE_LEFT, 'Image Left'),
    (POSITION_IMAGE_RIGHT, 'Image Right'),
)
