{% extends "admin/mptt_change_list.html" %}

{% block object-tools-items %}
    <li>
        <a href="{% url 'admin:glitter_pages_page_tree' %}" class="">
            Move pages
        </a>
    </li>
    {{ block.super }}
{% endblock object-tools-items %}
