{% extends "glitter/base.html" %}


{% block content %}
<div class="row">
    <div class="column">
        {{ columns.main }}
    </div>
    <div class="column">
        {{ columns.side }}
    </div>
    <div class="column">
        {{ columns.rside }}
    </div>
</div>
{% endblock content %}
