{% extends 'admin/glitter/dialog.html' %}

{% block title %}Deleting a block{% endblock %}

{% block form %}
    {% csrf_token %}
    <h2 class="glitter-message">Are you really, <i>really</i> sure you want to do that?</h2>
{% endblock %}

{% block buttons %}
    <input type="submit" value="Yes, delete it" class="glitter-form-delete" name="_save">
    <button class="glitter-form-button" onclick="window.parent.GlitterEditor.close_popup();return false;">No, thank you</button>
{% endblock %}
