html {
	margin: 0;
	padding: 0;
}
body {
	margin: 0;
	padding: 10px;
	font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
}

code,
pre {
	font-family: Menlo, Monaco, monospace, sans-serif;
}

div,
p,
ul,
ol,
table,
dl,
blockquote,
pre {
	font-size: 15px;
	line-height: 1.5rem;
}
div {
	border: 1px dashed #bbb !important;
}
a {
	color: #15c;
	text-decoration: underline;
}
.redactor_placeholder {
	color: #999 !important;
	display: block !important;
	margin-bottom: 10px !important;
}

object,
embed,
video,
img {
	max-width: 100%;
	width: auto;
}
video,
img {
	height: auto;
}

div,
p,
ul,
ol,
table,
dl,
blockquote,
pre {
	margin: 0;
	margin-bottom: 15px;
	border: none;
	background: none;
	box-shadow: none;
}
iframe,
object,
hr {
	margin-bottom: 15px;
}
blockquote {
	margin-left: 1.5em !important;
	padding-left: 0;
	color: #777;
	font-style: italic;
}
ul,
ol {
	padding-left: 2em;
}
ul ul,
ol ol,
ul ol,
ol ul {
	margin: 2px;
	padding: 0;
	padding-left: 2em;
	border: none;
}
dl dt { font-weight: bold; }
dd { margin-left: 1em;}

table {
	border-collapse: collapse;
	font-size: 1em;
}
table td {
	padding: 5px;
	border: 1px solid #ddd;
	vertical-align: top;
}
table thead td {
	border-bottom: 2px solid #000;
	font-weight: bold;
}
code {
	background-color: #d8d7d7;
}
pre {
	overflow: auto;
	padding: 1em;
	border: 1px solid #ddd;
	border-radius: 3px;
	background: #f8f8f8;
	white-space: pre;
	font-size: 90%;
}
hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
}

h1,
h2,
h3,
h4,
h5 {
	margin: 0;
	padding: 0;
	background: none;
	color: #000;
	font-weight: bold;
}

h1 {
	margin-bottom: 10px;
	font-size: 36px;
	line-height: 40px;
}
h2 {
	margin-bottom: 15px;
	font-size: 30px;
	line-height: 38px;
}
h3 {
	margin-bottom: 10px;
	font-size: 24px;
	line-height: 30px;
}
h4 {
	margin-bottom: 10px;
	font-size: 18px;
	line-height: 24px;
}
h5 {
	margin-bottom: 10px;
	font-size: 1em;
}

body.redactor_editor_wym {
	background: #f4f4f4;
}
.redactor_editor_wym div,
.redactor_editor_wym p,
.redactor_editor_wym ul,
.redactor_editor_wym ol,
.redactor_editor_wym table,
.redactor_editor_wym dl,
.redactor_editor_wym pre,
.redactor_editor_wym h1,
.redactor_editor_wym h2,
.redactor_editor_wym h3,
.redactor_editor_wym h4,
.redactor_editor_wym h5,
.redactor_editor_wym blockquote {
	margin: 0 0 10px 0;
	padding: 7px 10px;
	border: 1px solid #e4e4e4;
	background-color: #fff;
}
.redactor_editor_wym div {
	border: 1px dashed #bbb !important;
}
.redactor_editor_wym pre {
	border: 2px dashed #e4e4e4 !important;
	background-color: #fafafa !important;
}
.redactor_editor_wym code {
	background-color: #f4f4f4 !important;
}
.redactor_editor_wym ul,
.redactor_editor_wym ol {
	padding-left: 2em !important;
}
.redactor_editor_wym ul li ul,
.redactor_editor_wym ul li ol,
.redactor_editor_wym ol li ol,
.redactor_editor_wym ol li ul {
	border: none !important;
}

