{% if form %}
    <div class="{{ css_classes }}">
        <form method="POST" action=""{% if form.is_multipart %} enctype="multipart/form-data"{% endif %}>
            {% csrf_token %}
            {{ form.as_p }}
            <button type="submit">Submit</button>
        </form>
    </div>
{% endif %}
