/*
	Icon font
*/
@font-face {
  font-family: 'RedactorFont';
  src: url('redactor-font.eot');
}
@font-face {
  font-family: 'RedactorFont';
  src: url(data:application/x-font-ttf;charset=utf-8;base64, ) format('truetype'), url(data:application/font-woff;charset=utf-8;base64, ) format('woff');
  font-weight: normal;
  font-style: normal;
}
/* =Selection
-----------------------------------------------------------------------------*/
.redactor_box ::selection {
  background: #ffff9e;
}
.redactor_box ::-moz-selection {
  background: #ffff9e;
}
.redactor_box img::selection {
  background: transparent;
}
.redactor_box img::-moz-selection {
  background: transparent;
}
/*
	BOX
*/
.redactor_box {
  position: relative;
  overflow: visible;
  background: #fff;
}
.redactor_box iframe {
  display: block;
  margin: 0;
  padding: 0;
  border: 1px solid #eee;
}
.redactor_box textarea {
  position: relative;
  display: block;
  overflow: auto;
  margin: 0;
  padding: 0;
  width: 100%;
  outline: none;
  border: none;
  background-color: #222;
  box-shadow: none;
  color: #ccc;
  font-size: 13px;
  font-family: Menlo, Monaco, monospace, sans-serif;
  resize: none;
}
.redactor_box textarea:focus {
  outline: none;
}
.redactor_box,
.redactor_box textarea {
  z-index: auto !important;
}
.redactor_box_fullscreen {
  z-index: 99 !important;
}
#redactor_modal_overlay,
#redactor_modal,
.redactor_dropdown {
  z-index: 100 !important;
}
/*
	AIR

*/
body .redactor_air {
  position: absolute;
  z-index: 502;
}
/*
	FULLSCREEN
*/
body .redactor_box_fullscreen {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
}
/*
	LINK TOOLTIP
*/
.redactor-link-tooltip {
  position: absolute;
  z-index: 49999;
  padding: 10px;
  line-height: 1;
  display: inline-block;
  background-color: #000;
  color: #555 !important;
}
.redactor-link-tooltip,
.redactor-link-tooltip a {
  font-size: 12px;
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
}
.redactor-link-tooltip a {
  color: #ccc;
  margin: 0 5px;
  text-decoration: none;
}
.redactor-link-tooltip a:hover {
  color: #fff;
}
/*
	IMAGE BOX
*/
#redactor-image-box img {
  width: 100%;
}
.redactor_editor {
  position: relative;
  overflow: auto;
  margin: 0 !important;
  padding: 10px 20px;
  padding-bottom: 5px;
  outline: none;
  background: none;
  background: #fff;
  box-shadow: none !important;
  white-space: normal;
  border: 1px solid #eee;
}
.redactor_editor:focus {
  outline: none;
}
.redactor_editor div,
.redactor_editor p,
.redactor_editor ul,
.redactor_editor ol,
.redactor_editor table,
.redactor_editor dl,
.redactor_editor blockquote,
.redactor_editor pre,
.redactor_editor h1,
.redactor_editor h2,
.redactor_editor h3,
.redactor_editor h4,
.redactor_editor h5,
.redactor_editor h6 {
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
}
.redactor_editor code,
.redactor_editor pre {
  font-family: Menlo, Monaco, monospace, sans-serif;
}
.redactor_editor div,
.redactor_editor p,
.redactor_editor ul,
.redactor_editor ol,
.redactor_editor table,
.redactor_editor dl,
.redactor_editor blockquote,
.redactor_editor pre {
  font-size: 14px;
  line-height: 1.6em;
}
.redactor_editor a {
  color: #15c !important;
  text-decoration: underline !important;
}
.redactor_editor .redactor_placeholder {
  color: #999 !important;
  display: block !important;
}
/*
	TYPOGRAPHY
*/
.redactor_editor object,
.redactor_editor embed,
.redactor_editor video,
.redactor_editor img {
  max-width: 100%;
  width: auto;
}
.redactor_editor video,
.redactor_editor img {
  height: auto;
}
.redactor_editor div,
.redactor_editor p,
.redactor_editor ul,
.redactor_editor ol,
.redactor_editor table,
.redactor_editor dl,
.redactor_editor blockquote,
.redactor_editor pre {
  margin: 0;
  margin-bottom: 10px !important;
  border: none;
  background: none !important;
  box-shadow: none !important;
}
.redactor_editor iframe,
.redactor_editor object,
.redactor_editor hr {
  margin-bottom: 15px !important;
}
.redactor_editor blockquote {
  margin-left: 1.5em !important;
  padding-left: 0 !important;
  color: #777;
  font-style: italic !important;
}
.redactor_editor ul,
.redactor_editor ol {
  padding-left: 2em !important;
}
.redactor_editor ul ul,
.redactor_editor ol ol,
.redactor_editor ul ol,
.redactor_editor ol ul {
  margin: 2px !important;
  padding: 0 !important;
  padding-left: 2em !important;
  border: none;
}
.redactor_editor dl dt {
  font-weight: bold;
}
.redactor_editor dd {
  margin-left: 1em;
}
.redactor_editor table {
  border-collapse: collapse;
  font-size: 1em !important;
}
.redactor_editor table td {
  padding: 5px !important;
  border: 1px solid #ddd;
  vertical-align: top;
}
.redactor_editor table thead td {
  border-bottom: 2px solid #000 !important;
  font-weight: bold !important;
}
.redactor_editor code {
  background-color: #d8d7d7 !important;
}
.redactor_editor pre {
  overflow: auto;
  padding: 1em !important;
  border: 1px solid #ddd !important;
  border-radius: 3px !important;
  background: #f8f8f8 !important;
  white-space: pre;
  font-size: 90% !important;
}
.redactor_editor hr {
  display: block;
  height: 1px;
  border: 0;
  border-top: 1px solid #ccc;
}
/*
	HEADERS
*/
.redactor_editor h1,
.redactor_editor h2,
.redactor_editor h3,
.redactor_editor h4,
.redactor_editor h5,
.redactor_editor h6 {
  margin-top: 0 !important;
  padding: 0 !important;
  background: none;
  color: #000;
  font-weight: bold;
}
.redactor_editor h1 {
  font-size: 36px !important;
  line-height: 1.111em !important;
  margin-bottom: .15em !important;
}
.redactor_editor h2 {
  font-size: 30px !important;
  line-height: 1.111em !important;
  margin-bottom: .25em !important;
}
.redactor_editor h3 {
  font-size: 24px !important;
  line-height: 1.333em !important;
  margin-bottom: .2em !important;
}
.redactor_editor h4 {
  font-size: 18px !important;
  line-height: 1.5em !important;
  margin-bottom: .2em !important;
}
.redactor_editor h5 {
  font-size: 1em !important;
  line-height: 1.6em !important;
  margin-bottom: .25em !important;
}
.redactor_editor h6 {
  font-size: .8em !important;
  line-height: 1.6em !important;
  text-transform: uppercase;
  margin-bottom: .3em !important;
}
/*
	TOOLBAR
*/
.redactor_toolbar {
  position: relative;
  top: 0;
  left: 0;
  margin: 0 !important;
  padding: 0 !important;
  list-style: none !important;
  font-size: 14px !important;
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
  line-height: 1 !important;
  background: #fff;
  border: none;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2);
  z-index: 3;
}
.redactor_toolbar:after {
  content: "";
  display: table;
  clear: both;
}
.redactor_toolbar.redactor-toolbar-overflow {
  overflow-y: auto;
  height: 29px;
  white-space: nowrap;
}
.redactor_toolbar.redactor-toolbar-external {
  z-index: 999;
  box-shadow: none;
  border: 1px solid rgba(0, 0, 0, 0.1);
}
body .redactor_air .redactor_toolbar {
  padding-right: 2px !important;
}
.redactor_toolbar li {
  vertical-align: top;
  display: inline-block;
  margin: 0 !important;
  padding: 0 !important;
  outline: none;
  list-style: none !important;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.redactor_toolbar li a {
  display: block;
  color: #333;
  text-align: center;
  padding: 9px 10px;
  outline: none;
  border: none;
  text-decoration: none;
  cursor: pointer;
  zoom: 1;
  -webkit-box-sizing: content-box;
  -moz-box-sizing: content-box;
  box-sizing: content-box;
}
.redactor_toolbar li a:hover {
  outline: none;
  background-color: #1f78d8;
  color: #fff;
}
.redactor_toolbar li a:hover i:before {
  color: #fff;
}
.redactor_toolbar li a:active,
.redactor_toolbar li a.redactor_act {
  outline: none;
  background-color: #ccc;
  color: #444;
}
.redactor_toolbar li a.redactor-btn-image {
  width: 14px;
  height: 14px;
  background-position: center center;
  background-repeat: no-repeat;
}
.redactor_button_disabled {
  filter: alpha(opacity=30);
  -moz-opacity: 0.3;
  opacity: 0.3;
}
.redactor_button_disabled:hover {
  outline: none;
  background-color: transparent !important;
  cursor: default;
}
.redactor_toolbar li a.fa-redactor-btn {
  display: inline-block;
  padding: 9px 10px 8px 10px;
  line-height: 1;
}
.redactor_toolbar.redactor-toolbar-typewriter {
  box-shadow: none;
  background: rgba(240, 240, 240, 0.9);
}
.redactor_toolbar.redactor-toolbar-typewriter li a:hover {
  outline: none;
  background-color: #1f78d8;
  color: #fff;
}
.redactor_toolbar.redactor-toolbar-typewriter li a:active,
.redactor_toolbar.redactor-toolbar-typewriter li a.redactor_act {
  outline: none;
  background-color: #ccc;
  color: #444;
}
.re-icon {
  font-family: 'RedactorFont';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
}
.re-icon i:before {
  position: relative;
  font-size: 14px;
}
.re-video:before {
  content: "\e600";
}
.re-unorderedlist:before {
  content: "\e601";
}
.re-undo:before {
  content: "\e602";
}
.re-underline:before {
  content: "\e603";
}
.re-textdirection:before {
  content: "\e604";
}
.re-fontcolor:before {
  content: "\e605";
}
.re-table:before {
  content: "\e606";
}
.re-redo:before {
  content: "\e607";
}
.re-quote:before {
  content: "\e608";
}
.re-outdent:before {
  content: "\e609";
}
.re-orderedlist:before {
  content: "\e60a";
}
.re-link:before {
  content: "\e60b";
}
.re-horizontalrule:before {
  content: "\e60c";
}
.re-italic:before {
  content: "\e60d";
}
.re-indent:before {
  content: "\e60e";
}
.re-image:before {
  content: "\e60f";
}
.re-fullscreen:before {
  content: "\e610";
}
.re-normalscreen:before {
  content: "\e611";
}
.re-formatting:before {
  content: "\e612";
}
.re-fontsize:before {
  content: "\e613";
}
.re-fontfamily:before {
  content: "\e614";
}
.re-deleted:before {
  content: "\e615";
}
.re-html:before {
  content: "\e616";
}
.re-clips:before {
  content: "\e617";
}
.re-bold:before {
  content: "\e618";
}
.re-backcolor:before {
  content: "\e619";
}
.re-file:before {
  content: "\e61a";
}
.re-alignright:before {
  content: "\e61b";
}
.re-alignment:before,
.re-alignleft:before {
  content: "\e61c";
}
.re-alignjustify:before {
  content: "\e61d";
}
.re-aligncenter:before {
  content: "\e61e";
}
.re-gallery:before {
  content: "\e61f";
}
/*
	Toolbar classes
*/
.redactor_format_blockquote {
  padding-left: 10px;
  color: #666 !important;
  font-style: italic;
}
.redactor_format_pre {
  font-family: monospace, sans-serif;
}
.redactor_format_h1,
.redactor_format_h2,
.redactor_format_h3,
.redactor_format_h4,
.redactor_format_h5 {
  font-weight: bold;
}
.redactor_format_h1 {
  font-size: 30px;
  line-height: 36px;
}
.redactor_format_h2 {
  font-size: 24px;
  line-height: 36px;
}
.redactor_format_h3 {
  font-size: 20px;
  line-height: 30px;
}
.redactor_format_h4 {
  font-size: 16px;
  line-height: 26px;
}
.redactor_format_h5 {
  font-size: 14px;
  line-height: 23px;
}
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h1,
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h2,
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h3,
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h4,
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h5 {
  font-size: 1em;
  line-height: 1.6em;
  text-transform: uppercase;
}
.redactor-toolbar-typewriter .redactor_dropdown .redactor_format_h2 {
  font-size: .85em;
}
/*
	Typewriter
*/
.redactor_editor.redactor-editor-typewriter {
  background: #f5f5f5 !important;
  padding: 25px 50px !important;
}
.redactor_editor.redactor-editor-typewriter div,
.redactor_editor.redactor-editor-typewriter p,
.redactor_editor.redactor-editor-typewriter ul,
.redactor_editor.redactor-editor-typewriter ol,
.redactor_editor.redactor-editor-typewriter table,
.redactor_editor.redactor-editor-typewriter dl,
.redactor_editor.redactor-editor-typewriter blockquote,
.redactor_editor.redactor-editor-typewriter pre,
.redactor_editor.redactor-editor-typewriter h1,
.redactor_editor.redactor-editor-typewriter h2,
.redactor_editor.redactor-editor-typewriter h3,
.redactor_editor.redactor-editor-typewriter h4,
.redactor_editor.redactor-editor-typewriter h5,
.redactor_editor.redactor-editor-typewriter h6 {
  font-family: 'Courier New', 'Lucida Console', Consolas, Monaco, monospace, sans-serif;
  font-size: 18px !important;
  line-height: 1.5em !important;
  margin-bottom: 1.5em !important;
}
.redactor_editor.redactor-editor-typewriter h2 {
  font-size: 14px !important;
}
.redactor_editor.redactor-editor-typewriter h1,
.redactor_editor.redactor-editor-typewriter h2,
.redactor_editor.redactor-editor-typewriter h3,
.redactor_editor.redactor-editor-typewriter h4,
.redactor_editor.redactor-editor-typewriter h5,
.redactor_editor.redactor-editor-typewriter h6 {
  text-transform: uppercase;
}
.redactor_editor.redactor-editor-typewriter a {
  color: #000 !important;
  text-decoration: underline !important;
}
/*
	WYM
*/
.redactor_editor.redactor_editor_wym {
  padding: 10px 7px 0 7px !important;
  background: #f6f6f6 !important;
}
.redactor_editor.redactor_editor_wym div,
.redactor_editor.redactor_editor_wym p,
.redactor_editor.redactor_editor_wym ul,
.redactor_editor.redactor_editor_wym ol,
.redactor_editor.redactor_editor_wym table,
.redactor_editor.redactor_editor_wym dl,
.redactor_editor.redactor_editor_wym pre,
.redactor_editor.redactor_editor_wym h1,
.redactor_editor.redactor_editor_wym h2,
.redactor_editor.redactor_editor_wym h3,
.redactor_editor.redactor_editor_wym h4,
.redactor_editor.redactor_editor_wym h5,
.redactor_editor.redactor_editor_wym h6,
.redactor_editor.redactor_editor_wym blockquote {
  margin-top: 0;
  margin-bottom: 5px !important;
  padding: 10px !important;
  border: 1px solid #e4e4e4 !important;
  background-color: #fff !important;
  z-index: 0;
}
.redactor_editor.redactor_editor_wym blockquote:before {
  content: '';
}
.redactor_editor.redactor_editor_wym img {
  position: relative;
  z-index: 1;
}
.redactor_editor.redactor_editor_wym div {
  border: 1px dotted #aaa !important;
}
.redactor_editor.redactor_editor_wym pre {
  border: 2px dashed #e4e4e4 !important;
  background-color: #f8f8f8 !important;
}
.redactor_editor.redactor_editor_wym ul,
.redactor_editor.redactor_editor_wym ol {
  padding-left: 2em !important;
}
.redactor_editor.redactor_editor_wym ul li ul,
.redactor_editor.redactor_editor_wym ol li ul,
.redactor_editor.redactor_editor_wym ul li ol,
.redactor_editor.redactor_editor_wym ol li ol {
  border: none !important;
}
/*
	DROPDOWN
*/
.redactor_dropdown {
  position: absolute;
  top: 28px;
  left: 0;
  padding: 10px;
  width: 200px;
  background-color: #fff;
  box-shadow: 0 1px 5px #bbb;
  font-size: 13px;
  font-family: Helvetica, Arial, Verdana, Tahoma, sans-serif;
  line-height: 21px;
}
.redactor-toolbar-typewriter .redactor_dropdown {
  font-family: 'Courier New', 'Lucida Console', Consolas, Monaco, monospace, sans-serif;
  background-color: #f5f5f5;
}
.redactor_separator_drop {
  padding: 0 !important;
  border-top: 1px solid #ddd;
  font-size: 0;
  line-height: 0;
}
.redactor_dropdown a {
  display: block;
  padding: 3px 5px;
  color: #000;
  text-decoration: none;
}
.redactor_dropdown a:hover {
  background-color: #dde4ef;
  color: #444 !important;
  text-decoration: none;
}
/*
	MODAL
*/
#redactor_modal_overlay {
  position: fixed;
  top: 0;
  left: 0;
  margin: auto;
  width: 100%;
  height: 100%;
  background-color: #000 !important;
  filter: alpha(opacity=30);
  -moz-opacity: 0.3;
  opacity: 0.3;
}
#redactor_modal {
  position: fixed;
  top: 50%;
  left: 50%;
  padding: 0;
  background: #fff;
  color: #000;
  font-size: 12px !important;
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
  box-shadow: 0 1px 10px rgba(0, 0, 0, 0.5);
}
#redactor_modal header {
  padding: 20px 30px 5px 30px;
  font-size: 16px;
}
#redactor_modal section {
  padding: 20px 30px;
}
#redactor_modal label {
  display: block !important;
  float: none !important;
  margin: 10px 0 3px 0 !important;
  padding: 0 !important;
  font-size: 12px !important;
}
#redactor_modal footer:after {
  content: "";
  display: table;
  clear: both;
}
#redactor_modal footer div {
  float: left;
}
#redactor_modal input[type="radio"],
#redactor_modal input[type="checkbox"] {
  position: relative;
  top: -1px;
}
#redactor_modal input[type="text"],
#redactor_modal input[type="password"],
#redactor_modal input[type="email"],
#redactor_modal textarea {
  position: relative;
  z-index: 2;
  margin: 0;
  padding: 1px 2px;
  height: 23px;
  border: 1px solid #ccc;
  border-radius: 1px;
  background-color: white;
  box-shadow: 0 1px 2px rgba(0, 0, 0, 0.2) inset;
  color: #333;
  font-size: 13px;
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
  line-height: 1;
  -moz-transition: border 0.3s ease-in;
  transition: border 0.3s ease-in;
}
#redactor_modal textarea {
  display: block;
  margin-top: 4px;
  line-height: 1.4em;
}
#redactor_modal input:focus,
#redactor_modal textarea:focus {
  outline: none;
  border-color: #5ca9e4;
  box-shadow: 0 0 0 2px rgba(70, 161, 231, 0.3), 0 1px 2px rgba(0, 0, 0, 0.2) inset;
}
#redactor_modal_close {
  position: absolute;
  top: 5px;
  right: 3px;
  width: 20px;
  height: 20px;
  color: #999;
  font-size: 26px;
  cursor: pointer;
}
#redactor_modal_close:hover {
  color: #000;
}
.redactor_input {
  width: 99%;
  font-size: 14px;
}
.redactor_modal_box {
  overflow: auto;
  margin-bottom: 10px;
  height: 350px;
}
#redactor_image_box {
  overflow: auto;
  margin-bottom: 10px;
  height: 270px;
}
#redactor_image_box_select {
  display: block;
  margin-bottom: 15px !important;
  width: 200px;
}
#redactor_image_box img {
  margin-right: 10px;
  margin-bottom: 10px;
  max-width: 100px;
  cursor: pointer;
}
#redactor_tabs {
  margin-bottom: 18px;
}
#redactor_tabs a {
  display: inline-block;
  margin-right: 2px;
  padding: 4px 14px;
  border: 1px solid #d2d2d2;
  border-radius: 3px;
  background: #fff;
  color: #000;
  text-decoration: none;
  line-height: 1;
}
#redactor_tabs a:hover,
#redactor_tabs a.redactor_tabs_act {
  border-color: #eee;
  color: #999 !important;
  text-decoration: none !important;
}
.redactor_modal_btn_hidden {
  display: none;
}
#redactor_modal footer button {
  position: relative;
  width: 100%;
  padding: 10px 16px;
  margin: 0;
  outline: none;
  border: none;
  background-color: #ddd;
  color: #000;
  text-align: center;
  text-decoration: none;
  font-weight: normal;
  font-size: 12px;
  font-family: Arial, Helvetica, Verdana, Tahoma, sans-serif;
  line-height: 1;
  cursor: pointer;
}
#redactor_modal footer button:hover {
  color: #777;
  background: none;
  background: #bbb;
  text-decoration: none;
}
#redactor_modal footer button.redactor_modal_delete_btn {
  background: none;
  color: #fff;
  background-color: #b52525;
}
#redactor_modal footer button.redactor_modal_delete_btn:hover {
  color: rgba(255, 255, 255, 0.6);
  background-color: #881b1b;
}
#redactor_modal footer button.redactor_modal_action_btn {
  background: none;
  color: #fff;
  background-color: #2461b5;
}
#redactor_modal footer button.redactor_modal_action_btn:hover {
  color: rgba(255, 255, 255, 0.6);
  background-color: #1a4580;
}
/* Drag and Drop Area */
.redactor_droparea {
  position: relative;
  margin: auto;
  margin-bottom: 5px;
  width: 100%;
}
.redactor_droparea .redactor_dropareabox {
  position: relative;
  z-index: 1;
  padding: 60px 0;
  width: 99%;
  border: 1px dashed #ddd;
  background: #fff;
  text-align: center;
}
.redactor_droparea .redactor_dropareabox,
.redactor_dropalternative {
  color: #555;
  font-size: 12px;
}
.redactor_dropalternative {
  margin: 4px 0 2px 0;
}
.redactor_dropareabox.hover {
  border-color: #aaa;
  background: #efe3b8;
}
.redactor_dropareabox.error {
  border-color: #dcc3c3;
  background: #f7e5e5;
}
.redactor_dropareabox.drop {
  border-color: #e0e5d6;
  background: #f4f4ee;
}
/* =ProgressBar
-----------------------------------------------------------------------------*/
#redactor-progress {
  position: fixed;
  top: 0;
  left: 0;
  width: 100%;
  z-index: 1000000;
  height: 10px;
}
#redactor-progress span {
  display: block;
  width: 100%;
  height: 100%;
  background-color: #3d58a8;
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.2) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.2) 50%, rgba(255, 255, 255, 0.2) 75%, transparent 75%, transparent);
  -webkit-animation: progress-bar-stripes 2s linear infinite;
  -o-animation: progress-bar-stripes 2s linear infinite;
  animation: progress-bar-stripes 2s linear infinite;
  background-size: 40px 40px;
}
@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@-o-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}
