{% load static from staticfiles %}
{% load admin_urls %}
<link rel="stylesheet" href="{% static 'glitter/css/glitter.min.css' %}" />
<script src="{% static 'admin/js/jquery.min.js' %}"></script>
<script src="{% static 'glitter/js/jquery.cookie.js' %}"></script>
<script src="{% static 'glitter/js/jquery.simplePagination.js' %}"></script>
<script src="{% static 'glitter/js/glitter_editor.js' %}"></script>
<script type="text/javascript">
    GlitterEditor.store_csrf_token("{{ csrf_token }}");

    {% if edit_mode %}
        GlitterEditor.set_add_block_url("{% url glitter.opts|admin_urlname:'block_add' version_id=glitter.version.id %}");
    {% endif %}
</script>
