{% load admin_static %}{% load firstof from future %}<!DOCTYPE html>
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" {% if LANGUAGE_BIDI %}dir="rtl"{% endif %}>
<head>
<title>{% block title %}{% endblock %}</title>
<link rel="stylesheet" type="text/css" href="{% static 'glitter/css/djangoadmin.min.css' %}" />
{% block extrastyle %}{% endblock %}
<script type="text/javascript">window.__admin_media_prefix__ = "{% filter escapejs %}{% static "admin/" %}{% endfilter %}";</script>
<script type="text/javascript">window.__admin_utc_offset__ = "{% filter escapejs %}{% now "Z" %}{% endfilter %}";</script>
{% block extrahead %}{% endblock %}
{% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE" />{% endblock %}
</head>
{% load i18n %}

<body class="{% if is_popup %}popup {% endif %}{% block bodyclass %}{% endblock %}">

<!-- Container -->
<div id="container">

    <!-- Content -->
    <div id="content" class="{% block coltype %}colM{% endblock %} block-content">
        {% block pretitle %}{% endblock %}

        {% block content_title %}
            {% if title %}<h2>{{ title }}</h2>{% endif %}
            <hr/>
                

            <div class="control-area">
                <p>* required text</p>
                <a href="javascript:;" class="close" onclick="window.parent.GlitterEditor.close_popup();return false;">
                    Close
                </a>
            </div>
        {% endblock %}

        {% block content %}
        {% block object-tools %}{% endblock %}
        {{ content }}
        {% endblock %}
        {% block sidebar %}{% endblock %}
        <br class="clear" />
    </div>
    <!-- END Content -->

    {% block footer %}
        <div id="footer">
        </div>
    {% endblock %}
</div>
<!-- END Container -->

</body>
</html>
